%return the component feature vector of the character
%input: component_image: the component images, componentbox: the left-up 
%point and the right-down point position of every component's minimum bounding box.
%Author: Rongju Sun
%Email: rongjusun@gmail.com
%Date: Dec, 2014
%@Peking University, China

function component_feature_vect = fig_component(component_image, componentbox)
    component_feature_vect = [];
    
    component_num = size(componentbox, 1) / 2;
    if component_num == 1
       return; 
    end
    
    hm = {};wm = {};
    component_image_edge = {};
    startp = [];gravity = []; endp = [];
    
    %get the position and the gravity of the component's minimum bounding box
    for j = 1: component_num
        component_image_edge{j} = edge(component_image{j}, 'canny');
        
        [h_component, w_component] = size(component_image{j});
        [hm{j}, wm{j}] = find(component_image_edge{j} ~= 0);
        
        mstart = componentbox(2 * j - 1, :);

        startp(j, 1) = mstart(2);
        startp(j, 2) = mstart(1);
        gravity(j, 1) = startp(j, 1) + round(h_component / 2) - 1;
        gravity(j, 2) = startp(j, 2) + round(w_component / 2) - 1;
        endp(j, 1) = startp(j, 1) + h_component - 1;
        endp(j, 2) = startp(j, 2) + w_component - 1;

        hm{j} = hm{j} + mstart(2) - 1;
        wm{j} = wm{j} + mstart(1) - 1;
    end

    %calculate the distance and overlap of every two components 
    for m = 1: component_num - 1
       for n = m + 1 : component_num
          pnum_m = size(hm{m}, 1);
          pnum_n = size(hm{n}, 1);
          count = 0;
          maxdis = -1;
          mindis = 100000;
          meandisr = [];
          d = {};
          minh = min(startp(m, 1), startp(n, 1));
          minw = min(startp(m, 2), startp(n, 2));
          maxh = max(endp(m, 1), endp(n, 1));
          maxw = max(endp(m, 2), endp(n, 2));
          diagonal = sqrt((maxh - minh) ^ 2 + (maxw - minw) ^ 2);
          for p = 1: pnum_m
              for q = 1: pnum_n
                  d{p}(q) = sqrt((hm{m}(p) - hm{n}(q)) ^2 + (wm{m}(p) - wm{n}(q)) ^2);
                  if d{p}(q) > maxdis
                     maxdis = d{p}(q);
                     maxdis_p = [hm{m}(p), wm{m}(p), hm{n}(q), wm{n}(q)];
                  end
                  if d{p}(q) < mindis
                      mindis = d{p}(q);
                      mindis_p = [hm{m}(p), wm{m}(p), hm{n}(q), wm{n}(q)];
                  end
                  count = count + 1;
              end
              meandisr(p) = mean(d{p}(:));
          end

          meandis = mean(meandisr);

          Bbw = abs(gravity(m, 2) - gravity(n, 2))/(size(component_image{m}, 2) + size(component_image{n}, 2));
          Bvh = abs(gravity(m, 1) - gravity(n, 1))/(size(component_image{m}, 1) + size(component_image{n}, 1));
          interarea = IntersectArea(startp(m, :), endp(m, :), startp(n, :), endp(n, :));
          Bp = interarea/(size(component_image{m}, 2) * size(component_image{m}, 1) + size(component_image{n}, 2) * size(component_image{n}, 1) - interarea);
          component_feature_vect = [component_feature_vect, maxdis / diagonal, mindis / diagonal, meandis / diagonal];
          component_feature_vect = [component_feature_vect, Bbw, Bvh, Bp];
       end
    end

end
