%return the ratios of pixel distribution in quadrants
%Author: Rongju Sun
%Email: rongjusun@gmail.com
%Date: Dec, 2014
%@Peking University, China

function pixel_r = fig_gravity_conv(img)
    [h,w]=size(img);
    [x,y]=find(img==0);

    Xmax=max(x);
    Xmin=min(x);
    Ymax=max(y);
    Ymin=min(y);
    sum_rect=2*(Xmax-Xmin)+2*(Ymax-Ymin);
    Kcon=convhull(x,y);
    numPts=size(Kcon);
    conv_img=ones(h,w);
    img(:, :, 1) = img;
    img(:, :, 2) = img(:, :, 1);
    img(:, :, 3) = img(:, :, 2);
    for i=1:(numPts-1)
        vert0 = [x(Kcon(i)) y(Kcon(i))];
        vert1 = [x(Kcon(i+1)) y(Kcon(i+1))];
        vertLine_temp = DrawLine_DDA2d(vert0,vert1);
        numVexLine_temp = size(vertLine_temp,2);
        for l=1:numVexLine_temp
            img(vertLine_temp(1,l),vertLine_temp(2,l), 2)=0;
            img(vertLine_temp(1,l),vertLine_temp(2,l), 3)=0;
            conv_img(vertLine_temp(1,l),vertLine_temp(2,l))=0;
        end
    end
    
    %calculate the gravity of the convex hull
    sum_pixels_x=0;
    sum_pixels_y=0;
    sum_pt=0;
    for i=1:h
        I=find(conv_img(i,:)==0);
        if(isempty(I)) 
            continue;
        end
        minI=min(I);
        maxI=max(I);
        sum_pt=sum_pt+maxI-minI+1;
        sum_pixels_x=sum_pixels_x+(minI+maxI)*(maxI-minI+1)/2.0;
        sum_pixels_y=sum_pixels_y+i*(maxI-minI+1);
    end
    gravity_x=round(sum_pixels_x/sum_pt);
    gravity_y=round(sum_pixels_y/sum_pt);
    
    sum=zeros(2,2);
    for j=1:h
        I=find(conv_img(j,:)==0);
        if(isempty(I)) 
            continue;
        end
        minI=min(I);
        maxI=max(I);
        if(j<=gravity_y)
            for a=minI:gravity_x
                if(img(j,a)==0)
                    sum(1,1)=gravity_x-minI+1;
                end
            end
            for b=gravity_x:maxI
                if(img(j,b)==0)
                    sum(1,2)=maxI-gravity_x+1;
                end
            end
        else
            for a=minI:gravity_x
                if(img(j,a)==0)
                    sum(2,1)=gravity_x-minI+1;
                end
            end
            for b=gravity_x:maxI
                if(img(j,b)==0)
                    sum(2,2)=maxI-gravity_x+1;
                end
            end
        end
    end
    sum_pixel=sum(1,1)+sum(1,2)+sum(2,1)+sum(2,2);
    pixel_r(1)=sum(1,1)/sum_pixel;
    pixel_r(2)=sum(1,2)/sum_pixel;
    pixel_r(3)=sum(2,1)/sum_pixel;
    pixel_r(4)=sum(2,2)/sum_pixel;
end